==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebCancelableBrowserEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDescriptionMetadata } from "./WebCancelableEventArgsDescriptionMetadata";
import { WebCancelableBrowserEventArgsDescription } from "./WebCancelableBrowserEventArgsDescription";
/**
 * @hidden
 */
export let WebCancelableBrowserEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableBrowserEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableBrowserEventArgsDescriptionMetadata.a == null) {
                WebCancelableBrowserEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableBrowserEventArgsDescriptionMetadata.c(WebCancelableBrowserEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebCancelableBrowserEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebCancelableBrowserEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            WebCancelableEventArgsDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:CancelableBrowserEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebCancelableBrowserEventArgsDescriptionMetadata.b(a);
            a.ad("WebCancelableBrowserEventArgs", () => new WebCancelableBrowserEventArgsDescription());
            a.ac("WebCancelableBrowserEventArgs", WebCancelableBrowserEventArgsDescriptionMetadata.a);
        }
    }
    WebCancelableBrowserEventArgsDescriptionMetadata.$t = markType(WebCancelableBrowserEventArgsDescriptionMetadata, 'WebCancelableBrowserEventArgsDescriptionMetadata');
    WebCancelableBrowserEventArgsDescriptionMetadata.a = null;
    return WebCancelableBrowserEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebCancelableBrowserEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDescriptionMetadata } from "./WebCancelableEventArgsDescriptionMetadata";
import { WebCancelableBrowserEventArgsDescription } from "./WebCancelableBrowserEventArgsDescription";
/**
 * @hidden
 */
export let WebCancelableBrowserEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableBrowserEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableBrowserEventArgsDescriptionMetadata.a == null) {
                WebCancelableBrowserEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableBrowserEventArgsDescriptionMetadata.c(WebCancelableBrowserEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebCancelableBrowserEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebCancelableBrowserEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            WebCancelableEventArgsDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:CancelableBrowserEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebCancelableBrowserEventArgsDescriptionMetadata.b(a);
            a.ae("WebCancelableBrowserEventArgs", () => new WebCancelableBrowserEventArgsDescription());
            a.ad("WebCancelableBrowserEventArgs", WebCancelableBrowserEventArgsDescriptionMetadata.a);
        }
    }
    WebCancelableBrowserEventArgsDescriptionMetadata.$t = markType(WebCancelableBrowserEventArgsDescriptionMetadata, 'WebCancelableBrowserEventArgsDescriptionMetadata');
    WebCancelableBrowserEventArgsDescriptionMetadata.a = null;
    return WebCancelableBrowserEventArgsDescriptionMetadata;
})();
